@@ -1,27 +1,32 @@
 #! /usr/bin/env python2
 
-## Copyright (C) 2018 Leonardo Monteiro <decastromonteiro@gmail.com>
-##               2017 Alexis Sultan    <alexis.sultan@sfr.com>
-##               2017 Alessio Deiana <adeiana@gmail.com>
-##               2014 Guillaume Valadon <guillaume.valadon@ssi.gouv.fr>
-##               2012 ffranz <ffranz@iniqua.com>
+# Copyright (C) 2018 Leonardo Monteiro <decastromonteiro@gmail.com>
+#               2017 Alexis Sultan    <alexis.sultan@sfr.com>
+#               2017 Alessio Deiana <adeiana@gmail.com>
+#               2014 Guillaume Valadon <guillaume.valadon@ssi.gouv.fr>
+#               2012 ffranz <ffranz@iniqua.com>
 ##
-## This program is published under a GPLv2 license
+# This program is published under a GPLv2 license
 
-# scapy.contrib.description = GTP
+# scapy.contrib.description = GPRS Tunneling Protocol (GTP)
 # scapy.contrib.status = loads
 
 from __future__ import absolute_import
-import time
-import logging
+import struct
 
-from scapy.packet import *
-from scapy.fields import *
+
+from scapy.compat import chb, orb
+from scapy.error import warning
+from scapy.fields import BitEnumField, BitField, ByteEnumField, ByteField, \
+    ConditionalField, FieldLenField, FieldListField, FlagsField, IntField, \
+    IPField, PacketListField, ShortField, StrFixedLenField, StrLenField, \
+    XBitField, XByteField, XIntField
 from scapy.layers.inet import IP, UDP
 from scapy.layers.inet6 import IP6Field
-from scapy.error import warning
 from scapy.modules.six.moves import range
-from scapy.compat import chb, orb, plain_str
+from scapy.packet import bind_layers, Packet, Raw
+from scapy.volatile import RandInt, RandIP, RandNum, RandString
+
 
 # GTP Data types
 
@@ -33,59 +38,59 @@ RATType = {
     5: "HSPA"
 }
 
-GTPmessageType = {   1: "echo_request",
-                     2: "echo_response",
-                    16: "create_pdp_context_req",
-                    17: "create_pdp_context_res",
-                    18: "update_pdp_context_req",
-                    19: "update_pdp_context_resp",
-                    20: "delete_pdp_context_req",
-                    21: "delete_pdp_context_res",
-                    26: "error_indication",
-                    27: "pdu_notification_req",
-                    31: "supported_extension_headers_notification",
-                   254: "end_marker",
-                   255: "g_pdu" }
+GTPmessageType = {1: "echo_request",
+                  2: "echo_response",
+                  16: "create_pdp_context_req",
+                  17: "create_pdp_context_res",
+                  18: "update_pdp_context_req",
+                  19: "update_pdp_context_resp",
+                  20: "delete_pdp_context_req",
+                  21: "delete_pdp_context_res",
+                  26: "error_indication",
+                  27: "pdu_notification_req",
+                  31: "supported_extension_headers_notification",
+                  254: "end_marker",
+                  255: "g_pdu"}
 
-IEType = {   1: "Cause",
+IEType = {1: "Cause",
              2: "IMSI",
              3: "RAI",
              4: "TLLI",
              5: "P_TMSI",
              8: "IE_ReorderingRequired",
-            14: "Recovery",
-            15: "SelectionMode",
-            16: "TEIDI",
-            17: "TEICP",
-            19: "TeardownInd",
-            20: "NSAPI",
-            26: "ChargingChrt",
-            27: "TraceReference",
-            28: "TraceType",
-           127: "ChargingId",
-           128: "EndUserAddress",
-           131: "AccessPointName",
-           132: "ProtocolConfigurationOptions",
-           133: "GSNAddress",
-           134: "MSInternationalNumber",
-           135: "QoS",
-           148: "CommonFlags",
-           149: "APNRestriction",
-           151: "RatType",
-           152: "UserLocationInformation",
-           153: "MSTimeZone",
-           154: "IMEI",
-           181: "MSInfoChangeReportingAction",
-           184: "BearerControlMode",
-           191: "EvolvedAllocationRetentionPriority",
-           255: "PrivateExtention"}
+          14: "Recovery",
+          15: "SelectionMode",
+          16: "TEIDI",
+          17: "TEICP",
+          19: "TeardownInd",
+          20: "NSAPI",
+          26: "ChargingChrt",
+          27: "TraceReference",
+          28: "TraceType",
+          127: "ChargingId",
+          128: "EndUserAddress",
+          131: "AccessPointName",
+          132: "ProtocolConfigurationOptions",
+          133: "GSNAddress",
+          134: "MSInternationalNumber",
+          135: "QoS",
+          148: "CommonFlags",
+          149: "APNRestriction",
+          151: "RatType",
+          152: "UserLocationInformation",
+          153: "MSTimeZone",
+          154: "IMEI",
+          181: "MSInfoChangeReportingAction",
+          184: "BearerControlMode",
+          191: "EvolvedAllocationRetentionPriority",
+          255: "PrivateExtention"}
 
-CauseValues = {  0: "Request IMSI",
-                 1: "Request IMEI",
-                 2: "Request IMSI and IMEI",
-                 3: "No identity needed",
-                 4: "MS Refuses",
-                 5: "MS is not GPRS Responding",
+CauseValues = {0: "Request IMSI",
+               1: "Request IMEI",
+               2: "Request IMSI and IMEI",
+               3: "No identity needed",
+               4: "MS Refuses",
+               5: "MS is not GPRS Responding",
                128: "Request accepted",
                129: "New PDP type due to network preference",
                130: "New PDP type due to single address bearer only",
@@ -120,31 +125,31 @@ CauseValues = {  0: "Request IMSI",
                220: "Unknown PDP address or PDP type",
                221: "PDP context without TFT already activated",
                222: "APN access denied : no subscription",
-               223: "APN Restriction type incompatibility with currently active PDP Contexts",
+               223: "APN Restriction type incompatibility with currently active PDP Contexts",  # noqa: E501
                224: "MS MBMS Capabilities Insufficient",
                225: "Invalid Correlation : ID",
                226: "MBMS Bearer Context Superseded",
                227: "Bearer Control Mode violation",
-               228: "Collision with network initiated request" }
+               228: "Collision with network initiated request"}
 
-Selection_Mode = { 11111100: "MS or APN",
-                   11111101: "MS",
-                   11111110: "NET",
-                   11111111: "FutureUse" }
+Selection_Mode = {11111100: "MS or APN",
+                  11111101: "MS",
+                  11111110: "NET",
+                  11111111: "FutureUse"}
 
 TrueFalse_value = {254: "False",
                    255: "True"}
 
 # http://www.arib.or.jp/IMT-2000/V720Mar09/5_Appendix/Rel8/29/29281-800.pdf
 ExtensionHeadersTypes = {
-        0: "No more extension headers",
-        1: "Reserved",
-        2: "Reserved",
-        64: "UDP Port",
-        192: "PDCP PDU Number",
-        193: "Reserved",
-        194: "Reserved"
-    }
+    0: "No more extension headers",
+    1: "Reserved",
+    2: "Reserved",
+    64: "UDP Port",
+    192: "PDCP PDU Number",
+    193: "Reserved",
+    194: "Reserved"
+}
 
 
 class TBCDByteField(StrFixedLenField):
@@ -161,62 +166,65 @@ class TBCDByteField(StrFixedLenField):
             if left == 0xf:
                 ret.append(TBCD_TO_ASCII[right:right + 1])
             else:
-                ret += [TBCD_TO_ASCII[right:right + 1], TBCD_TO_ASCII[left:left + 1]]
+                ret += [TBCD_TO_ASCII[right:right + 1], TBCD_TO_ASCII[left:left + 1]]  # noqa: E501
         return b"".join(ret)
 
     def i2m(self, pkt, val):
         val = str(val)
         ret_string = ""
         for i in range(0, len(val), 2):
-            tmp = val[i:i+2]
+            tmp = val[i:i + 2]
             if len(tmp) == 2:
-              ret_string += chr(int(tmp[1] + tmp[0], 16))
+                ret_string += chr(int(tmp[1] + tmp[0], 16))
             else:
-              ret_string += chr(int("F" + tmp[0], 16))
+                ret_string += chr(int("F" + tmp[0], 16))
         return ret_string
 
 
 TBCD_TO_ASCII = b"0123456789*#abc"
 
+
 class GTP_ExtensionHeader(Packet):
     @classmethod
     def dispatch_hook(cls, _pkt=None, *args, **kargs):
-        if _pkt == None:
+        if _pkt is None:
             return GTP_UDPPort_ExtensionHeader
         return cls
 
+
 class GTP_UDPPort_ExtensionHeader(GTP_ExtensionHeader):
-    fields_desc=[ ByteField("length", 0x40),
-                  ShortField("udp_port", None),
-                  ByteEnumField("next_ex", 0, ExtensionHeadersTypes), ]
+    fields_desc = [ByteField("length", 0x40),
+                   ShortField("udp_port", None),
+                   ByteEnumField("next_ex", 0, ExtensionHeadersTypes), ]
+
 
 class GTP_PDCP_PDU_ExtensionHeader(GTP_ExtensionHeader):
-    fields_desc=[ ByteField("length", 0x01),
-                  ShortField("pdcp_pdu", None),
-                  ByteEnumField("next_ex", 0, ExtensionHeadersTypes), ]
-    
+    fields_desc = [ByteField("length", 0x01),
+                   ShortField("pdcp_pdu", None),
+                   ByteEnumField("next_ex", 0, ExtensionHeadersTypes), ]
+
 
 class GTPHeader(Packet):
     # 3GPP TS 29.060 V9.1.0 (2009-12)
     name = "GTP-C Header"
-    fields_desc=[ BitField("version", 1, 3),
-                  BitField("PT", 1, 1),
-                  BitField("reserved", 0, 1),
-                  BitField("E", 0, 1),
-                  BitField("S", 0, 1),
-                  BitField("PN", 0, 1),
-                  ByteEnumField("gtp_type", None, GTPmessageType),
-                  ShortField("length", None),
-                  IntField("teid", 0),
-                  ConditionalField(XBitField("seq", 0, 16), lambda pkt:pkt.E==1 or pkt.S==1 or pkt.PN==1),
-                  ConditionalField(ByteField("npdu", 0), lambda pkt:pkt.E==1 or pkt.S==1 or pkt.PN==1),
-                  ConditionalField(ByteEnumField("next_ex", 0, ExtensionHeadersTypes), lambda pkt:pkt.E==1 or pkt.S==1 or pkt.PN==1), ]
+    fields_desc = [BitField("version", 1, 3),
+                   BitField("PT", 1, 1),
+                   BitField("reserved", 0, 1),
+                   BitField("E", 0, 1),
+                   BitField("S", 0, 1),
+                   BitField("PN", 0, 1),
+                   ByteEnumField("gtp_type", None, GTPmessageType),
+                   ShortField("length", None),
+                   IntField("teid", 0),
+                   ConditionalField(XBitField("seq", 0, 16), lambda pkt:pkt.E == 1 or pkt.S == 1 or pkt.PN == 1),  # noqa: E501
+                   ConditionalField(ByteField("npdu", 0), lambda pkt:pkt.E == 1 or pkt.S == 1 or pkt.PN == 1),  # noqa: E501
+                   ConditionalField(ByteEnumField("next_ex", 0, ExtensionHeadersTypes), lambda pkt:pkt.E == 1 or pkt.S == 1 or pkt.PN == 1), ]  # noqa: E501
 
     def post_build(self, p, pay):
         p += pay
         if self.length is None:
-            l = len(p)-8
-            p = p[:2] + struct.pack("!H", l)+ p[4:]
+            tmp_len = len(p) - 8
+            p = p[:2] + struct.pack("!H", tmp_len) + p[4:]
         return p
 
     def hashret(self):
@@ -238,12 +246,14 @@ class GTPHeader(Packet):
             return GTPforcedTypes.get(_gtp_type, GTPHeader)
         return cls
 
+
 class GTP_U_Header(GTPHeader):
     # 3GPP TS 29.060 V9.1.0 (2009-12)
     name = "GTP-U Header"
-    # GTP-U protocol is used to transmit T-PDUs between GSN pairs (or between an SGSN and an RNC in UMTS), 
-    # encapsulated in G-PDUs. A G-PDU is a packet including a GTP-U header and a T-PDU. The Path Protocol 
-    # defines the path and the GTP-U header defines the tunnel. Several tunnels may be multiplexed on a single path.
+    # GTP-U protocol is used to transmit T-PDUs between GSN pairs (or between an SGSN and an RNC in UMTS),  # noqa: E501
+    # encapsulated in G-PDUs. A G-PDU is a packet including a GTP-U header and a T-PDU. The Path Protocol  # noqa: E501
+    # defines the path and the GTP-U header defines the tunnel. Several tunnels may be multiplexed on a single path.  # noqa: E501
+
 
 # Some gtp_types have to be associated with a certain type of header
 GTPforcedTypes = {
@@ -257,7 +267,8 @@ GTPforcedTypes = {
     27: GTPHeader,
     254: GTP_U_Header,
     255: GTP_U_Header
-    }
+}
+
 
 class GTPEchoRequest(Packet):
     # 3GPP TS 29.060 V9.1.0 (2009-12)
@@ -287,13 +298,13 @@ class IE_IMSI(IE_Base):
 
 class IE_Routing(IE_Base):
     name = "Routing Area Identity"
-    fields_desc = [ ByteEnumField("ietype", 3, IEType),
-                    TBCDByteField("MCC", "", 2),
-                    # MNC: if the third digit of MCC is 0xf,
-                    # then the length of MNC is 1 byte
-                    TBCDByteField("MNC", "", 1),
-                    ShortField("LAC", None),
-                    ByteField("RAC", None) ]
+    fields_desc = [ByteEnumField("ietype", 3, IEType),
+                   TBCDByteField("MCC", "", 2),
+                   # MNC: if the third digit of MCC is 0xf,
+                   # then the length of MNC is 1 byte
+                   TBCDByteField("MNC", "", 1),
+                   ShortField("LAC", None),
+                   ByteField("RAC", None)]
 
 
 class IE_ReorderingRequired(IE_Base):
@@ -304,74 +315,75 @@ class IE_ReorderingRequired(IE_Base):
 
 class IE_Recovery(IE_Base):
     name = "Recovery"
-    fields_desc = [ ByteEnumField("ietype", 14, IEType),
-                    ByteField("restart_counter", 24) ]
+    fields_desc = [ByteEnumField("ietype", 14, IEType),
+                   ByteField("restart_counter", 24)]
 
 
 class IE_SelectionMode(IE_Base):
     # Indicates the origin of the APN in the message
     name = "Selection Mode"
-    fields_desc = [ ByteEnumField("ietype", 15, IEType),
-                    BitEnumField("SelectionMode", "MS or APN", 
-                                 8, Selection_Mode) ]
+    fields_desc = [ByteEnumField("ietype", 15, IEType),
+                   BitEnumField("SelectionMode", "MS or APN",
+                                8, Selection_Mode)]
 
 
 class IE_TEIDI(IE_Base):
     name = "Tunnel Endpoint Identifier Data"
-    fields_desc = [ ByteEnumField("ietype", 16, IEType),
-                    XIntField("TEIDI", RandInt()) ]
+    fields_desc = [ByteEnumField("ietype", 16, IEType),
+                   XIntField("TEIDI", RandInt())]
 
 
 class IE_TEICP(IE_Base):
     name = "Tunnel Endpoint Identifier Control Plane"
-    fields_desc = [ ByteEnumField("ietype", 17, IEType),
-                    XIntField("TEICI", RandInt())]
+    fields_desc = [ByteEnumField("ietype", 17, IEType),
+                   XIntField("TEICI", RandInt())]
 
 
 class IE_Teardown(IE_Base):
     name = "Teardown Indicator"
-    fields_desc = [ ByteEnumField("ietype", 19, IEType),
-                    ByteEnumField("indicator", "True", TrueFalse_value) ]
+    fields_desc = [ByteEnumField("ietype", 19, IEType),
+                   ByteEnumField("indicator", "True", TrueFalse_value)]
 
 
 class IE_NSAPI(IE_Base):
-    # Identifies a PDP context in a mobility management context specified by TEICP
+    # Identifies a PDP context in a mobility management context specified by TEICP  # noqa: E501
     name = "NSAPI"
-    fields_desc = [ ByteEnumField("ietype", 20, IEType),
-                    XBitField("sparebits", 0x0000, 4),
-                    XBitField("NSAPI", RandNum(0, 15), 4) ]
+    fields_desc = [ByteEnumField("ietype", 20, IEType),
+                   XBitField("sparebits", 0x0000, 4),
+                   XBitField("NSAPI", RandNum(0, 15), 4)]
 
 
 class IE_ChargingCharacteristics(IE_Base):
-    # Way of informing both the SGSN and GGSN of the rules for 
+    # Way of informing both the SGSN and GGSN of the rules for
     name = "Charging Characteristics"
-    fields_desc = [ ByteEnumField("ietype", 26, IEType),
-                    # producing charging information based on operator configured triggers.
-                    #    0000 .... .... .... : spare
-                    #    .... 1... .... .... : normal charging
-                    #    .... .0.. .... .... : prepaid charging
-                    #    .... ..0. .... .... : flat rate charging
-                    #    .... ...0 .... .... : hot billing charging
-                    #    .... .... 0000 0000 : reserved
-                    XBitField("Ch_ChSpare", None, 4),
-                    XBitField("normal_charging", None, 1),
-                    XBitField("prepaid_charging", None, 1),
-                    XBitField("flat_rate_charging", None, 1),
-                    XBitField("hot_billing_charging", None, 1),
-                    XBitField("Ch_ChReserved", 0, 8) ]
+    fields_desc = [ByteEnumField("ietype", 26, IEType),
+                   # producing charging information based on operator configured triggers.  # noqa: E501
+                   #    0000 .... .... .... : spare
+                   #    .... 1... .... .... : normal charging
+                   #    .... .0.. .... .... : prepaid charging
+                   #    .... ..0. .... .... : flat rate charging
+                   #    .... ...0 .... .... : hot billing charging
+                   #    .... .... 0000 0000 : reserved
+                   XBitField("Ch_ChSpare", None, 4),
+                   XBitField("normal_charging", None, 1),
+                   XBitField("prepaid_charging", None, 1),
+                   XBitField("flat_rate_charging", None, 1),
+                   XBitField("hot_billing_charging", None, 1),
+                   XBitField("Ch_ChReserved", 0, 8)]
+
 
 class IE_TraceReference(IE_Base):
     # Identifies a record or a collection of records for a particular trace.
     name = "Trace Reference"
-    fields_desc = [ ByteEnumField("ietype", 27, IEType),
-                    XBitField("Trace_reference", None, 16) ]
+    fields_desc = [ByteEnumField("ietype", 27, IEType),
+                   XBitField("Trace_reference", None, 16)]
 
 
 class IE_TraceType(IE_Base):
     # Indicates the type of the trace
     name = "Trace Type"
-    fields_desc = [ ByteEnumField("ietype", 28, IEType),
-                    XBitField("Trace_type", None, 16) ]
+    fields_desc = [ByteEnumField("ietype", 28, IEType),
+                   XBitField("Trace_type", None, 16)]
 
 
 class IE_ChargingId(IE_Base):
@@ -381,25 +393,25 @@ class IE_ChargingId(IE_Base):
 
 
 class IE_EndUserAddress(IE_Base):
-    # Supply protocol specific information of the external packet 
-    name = "End User Addresss"
-    fields_desc = [ ByteEnumField("ietype", 128, IEType),
-                    #         data network accessed by the GGPRS subscribers.
-                    #            - Request
-                    #                1    Type (1byte)
-                    #                2-3    Length (2bytes) - value 2
-                    #                4    Spare + PDP Type Organization
-                    #                5    PDP Type Number    
-                    #            - Response
-                    #                6-n    PDP Address
-                    ShortField("length", 2),
-                    BitField("SPARE", 15, 4),
-                    BitField("PDPTypeOrganization", 1, 4),
-                    XByteField("PDPTypeNumber", None),
-                    ConditionalField(IPField("PDPAddress", RandIP()),
-                                     lambda pkt: pkt.length == 6 or pkt.length == 22),
-                    ConditionalField(IP6Field("IPv6_PDPAddress", '::1'),
-                                     lambda pkt: pkt.length == 18 or pkt.length == 22)]
+    # Supply protocol specific information of the external packet
+    name = "End User Address"
+    fields_desc = [ByteEnumField("ietype", 128, IEType),
+                   #         data network accessed by the GGPRS subscribers.
+                   #            - Request
+                   #                1    Type (1byte)
+                   #                2-3    Length (2bytes) - value 2
+                   #                4    Spare + PDP Type Organization
+                   #                5    PDP Type Number
+                   #            - Response
+                   #                6-n    PDP Address
+                   ShortField("length", 2),
+                   BitField("SPARE", 15, 4),
+                   BitField("PDPTypeOrganization", 1, 4),
+                   XByteField("PDPTypeNumber", None),
+                   ConditionalField(IPField("PDPAddress", RandIP()),
+                                    lambda pkt: pkt.length == 6 or pkt.length == 22),  # noqa: E501
+                   ConditionalField(IP6Field("IPv6_PDPAddress", '::1'),
+                                    lambda pkt: pkt.length == 18 or pkt.length == 22)]  # noqa: E501
 
 
 class APNStrLenField(StrLenField):
@@ -410,13 +422,14 @@ class APNStrLenField(StrLenField):
         while tmp_s:
             tmp_len = orb(tmp_s[0]) + 1
             if tmp_len > len(tmp_s):
-                warning("APN prematured end of character-string (size=%i, remaining bytes=%i)" % (tmp_len, len(tmp_s)))
-            ret_s +=  tmp_s[1:tmp_len] 
+                warning("APN prematured end of character-string (size=%i, remaining bytes=%i)" % (tmp_len, len(tmp_s)))  # noqa: E501
+            ret_s += tmp_s[1:tmp_len]
             tmp_s = tmp_s[tmp_len:]
-            if len(tmp_s) :
+            if len(tmp_s):
                 ret_s += b"."
         s = ret_s
         return s
+
     def i2m(self, pkt, s):
         s = b"".join(chb(len(x)) + x for x in s.split("."))
         return s
@@ -425,38 +438,38 @@ class APNStrLenField(StrLenField):
 class IE_AccessPointName(IE_Base):
     # Sent by SGSN or by GGSN as defined in 3GPP TS 23.060
     name = "Access Point Name"
-    fields_desc = [ ByteEnumField("ietype", 131, IEType),
-                    ShortField("length",  None),
-                    APNStrLenField("APN", "nternet", length_from=lambda x: x.length) ]
+    fields_desc = [ByteEnumField("ietype", 131, IEType),
+                   ShortField("length", None),
+                   APNStrLenField("APN", "nternet", length_from=lambda x: x.length)]  # noqa: E501
 
     def post_build(self, p, pay):
         if self.length is None:
-            l = len(p)-3
-            p = p[:2] + struct.pack("!B", l)+ p[3:]
+            tmp_len = len(p) - 3
+            p = p[:2] + struct.pack("!B", tmp_len) + p[3:]
         return p
 
 
 class IE_ProtocolConfigurationOptions(IE_Base):
     name = "Protocol Configuration Options"
-    fields_desc = [ ByteEnumField("ietype", 132, IEType),
-            ShortField("length", 4),
-            StrLenField("Protocol_Configuration", "", 
-                        length_from=lambda x: x.length) ]
+    fields_desc = [ByteEnumField("ietype", 132, IEType),
+                   ShortField("length", 4),
+                   StrLenField("Protocol_Configuration", "",
+                               length_from=lambda x: x.length)]
 
 
 class IE_GSNAddress(IE_Base):
     name = "GSN Address"
-    fields_desc = [ ByteEnumField("ietype", 133, IEType),
-                    ShortField("length", 4),
-                    IPField("address", RandIP()) ]
+    fields_desc = [ByteEnumField("ietype", 133, IEType),
+                   ShortField("length", 4),
+                   IPField("address", RandIP())]
 
 
 class IE_MSInternationalNumber(IE_Base):
     name = "MS International Number"
-    fields_desc = [ ByteEnumField("ietype", 134, IEType),
-                    ShortField("length", None),
-                    FlagsField("flags", 0x91, 8, ["Extension","","","International Number","","","","ISDN numbering"]),
-                    TBCDByteField("digits", "33607080910", length_from=lambda x: x.length-1) ]
+    fields_desc = [ByteEnumField("ietype", 134, IEType),
+                   ShortField("length", None),
+                   FlagsField("flags", 0x91, 8, ["Extension", "", "", "International Number", "", "", "", "ISDN numbering"]),  # noqa: E501
+                   TBCDByteField("digits", "33607080910", length_from=lambda x: x.length - 1)]  # noqa: E501
 
 
 class QoS_Profile(IE_Base):
@@ -600,15 +613,15 @@ class IE_RATType(IE_Base):
 
 class IE_UserLocationInformation(IE_Base):
     name = "User Location Information"
-    fields_desc = [ ByteEnumField("ietype", 152, IEType),
-                    ShortField("length", None),
-                    ByteField("type", 1),
-                    # Only type 1 is currently supported
-                    TBCDByteField("MCC", "", 2),
-                    # MNC: if the third digit of MCC is 0xf, then the length of MNC is 1 byte
-                    TBCDByteField("MNC", "", 1),
-                    ShortField("LAC", None),
-                    ShortField("SAC", None) ]
+    fields_desc = [ByteEnumField("ietype", 152, IEType),
+                   ShortField("length", None),
+                   ByteField("type", 1),
+                   # Only type 1 is currently supported
+                   TBCDByteField("MCC", "", 2),
+                   # MNC: if the third digit of MCC is 0xf, then the length of MNC is 1 byte  # noqa: E501
+                   TBCDByteField("MNC", "", 1),
+                   ShortField("LAC", None),
+                   ShortField("SAC", None)]
 
 
 class IE_MSTimeZone(IE_Base):
@@ -627,9 +640,9 @@ class IE_MSTimeZone(IE_Base):
 
 class IE_IMEI(IE_Base):
     name = "IMEI"
-    fields_desc = [ ByteEnumField("ietype", 154, IEType),
-                    ShortField("length", None),
-                    TBCDByteField("IMEI", "", length_from=lambda x: x.length) ]
+    fields_desc = [ByteEnumField("ietype", 154, IEType),
+                   ShortField("length", None),
+                   TBCDByteField("IMEI", "", length_from=lambda x: x.length)]
 
 
 class IE_MSInfoChangeReportingAction(IE_Base):
@@ -690,19 +703,22 @@ class IE_PrivateExtension(IE_Base):
                    StrLenField("extention_value", "",
                                length_from=lambda x: x.length)]
 
+
 class IE_ExtensionHeaderList(IE_Base):
     name = "Extension Header List"
     fields_desc = [ByteEnumField("ietype", 141, IEType),
-                   FieldLenField("length", None, length_of="extension_headers"),
-                   FieldListField("extension_headers", [64, 192], ByteField("", 0))]
+                   FieldLenField("length", None, length_of="extension_headers"),  # noqa: E501
+                   FieldListField("extension_headers", [64, 192], ByteField("", 0))]  # noqa: E501
+
 
 class IE_NotImplementedTLV(Packet):
     name = "IE not implemented"
-    fields_desc = [ ByteEnumField("ietype", 0, IEType),
-                    ShortField("length",  None),
-                    StrLenField("data", "", length_from=lambda x: x.length) ]
+    fields_desc = [ByteEnumField("ietype", 0, IEType),
+                   ShortField("length", None),
+                   StrLenField("data", "", length_from=lambda x: x.length)]
+
     def extract_padding(self, pkt):
-        return "",pkt
+        return "", pkt
 
 
 ietypecls = {1: IE_Cause,
@@ -753,10 +769,11 @@ def IE_Dispatcher(s):
         cls = IE_NotImplementedTLV
     return cls(s)
 
+
 class GTPEchoResponse(Packet):
     # 3GPP TS 29.060 V9.1.0 (2009-12)
     name = "GTP Echo Response"
-    fields_desc = [ PacketListField("IE_list", [], IE_Dispatcher) ]
+    fields_desc = [PacketListField("IE_list", [], IE_Dispatcher)]
 
     def hashret(self):
         return struct.pack("H", self.seq)
@@ -768,17 +785,19 @@ class GTPEchoResponse(Packet):
 class GTPCreatePDPContextRequest(Packet):
     # 3GPP TS 29.060 V9.1.0 (2009-12)
     name = "GTP Create PDP Context Request"
-    fields_desc = [ PacketListField("IE_list", [ IE_TEIDI(), IE_NSAPI(), IE_GSNAddress(),
-                                                 IE_GSNAddress(),
-                                                 IE_NotImplementedTLV(ietype=135, length=15,data=RandString(15)) ],
-                                    IE_Dispatcher) ]
+    fields_desc = [PacketListField("IE_list", [IE_TEIDI(), IE_NSAPI(), IE_GSNAddress(),  # noqa: E501
+                                               IE_GSNAddress(),
+                                               IE_NotImplementedTLV(ietype=135, length=15, data=RandString(15))],  # noqa: E501
+                                   IE_Dispatcher)]
+
     def hashret(self):
         return struct.pack("H", self.seq)
 
+
 class GTPCreatePDPContextResponse(Packet):
     # 3GPP TS 29.060 V9.1.0 (2009-12)
     name = "GTP Create PDP Context Response"
-    fields_desc = [ PacketListField("IE_list", [], IE_Dispatcher) ]
+    fields_desc = [PacketListField("IE_list", [], IE_Dispatcher)]
 
     def hashret(self):
         return struct.pack("H", self.seq)
@@ -791,25 +810,25 @@ class GTPUpdatePDPContextRequest(Packet):
     # 3GPP TS 29.060 V9.1.0 (2009-12)
     name = "GTP Update PDP Context Request"
     fields_desc = [PacketListField("IE_list", [
-                       IE_Cause(),
-                       IE_Recovery(),
-                       IE_TEIDI(),
-                       IE_TEICP(),
-                       IE_ChargingId(),
-                       IE_ProtocolConfigurationOptions(),
-                       IE_GSNAddress(),
-                       IE_GSNAddress(),
-                       IE_GSNAddress(),
-                       IE_GSNAddress(),
-                       IE_QoS(),
-                       IE_CharginGatewayAddress(),
-                       IE_CharginGatewayAddress(),
-                       IE_CommonFlags(),
-                       IE_APNRestriction(),
-                       IE_BearerControlMode(),
-                       IE_MSInfoChangeReportingAction(),
-                       IE_EvolvedAllocationRetentionPriority(),
-                       IE_PrivateExtension()],
+        IE_Cause(),
+        IE_Recovery(),
+        IE_TEIDI(),
+        IE_TEICP(),
+        IE_ChargingId(),
+        IE_ProtocolConfigurationOptions(),
+        IE_GSNAddress(),
+        IE_GSNAddress(),
+        IE_GSNAddress(),
+        IE_GSNAddress(),
+        IE_QoS(),
+        IE_CharginGatewayAddress(),
+        IE_CharginGatewayAddress(),
+        IE_CommonFlags(),
+        IE_APNRestriction(),
+        IE_BearerControlMode(),
+        IE_MSInfoChangeReportingAction(),
+        IE_EvolvedAllocationRetentionPriority(),
+        IE_PrivateExtension()],
         IE_Dispatcher)]
 
     def hashret(self):
@@ -828,46 +847,48 @@ class GTPUpdatePDPContextResponse(Packet):
 class GTPErrorIndication(Packet):
     # 3GPP TS 29.060 V9.1.0 (2009-12)
     name = "GTP Error Indication"
-    fields_desc = [ PacketListField("IE_list", [], IE_Dispatcher) ]
+    fields_desc = [PacketListField("IE_list", [], IE_Dispatcher)]
+
 
 class GTPDeletePDPContextRequest(Packet):
     # 3GPP TS 29.060 V9.1.0 (2009-12)
     name = "GTP Delete PDP Context Request"
-    fields_desc = [ PacketListField("IE_list", [], IE_Dispatcher) ]
+    fields_desc = [PacketListField("IE_list", [], IE_Dispatcher)]
+
 
 class GTPDeletePDPContextResponse(Packet):
     # 3GPP TS 29.060 V9.1.0 (2009-12)
     name = "GTP Delete PDP Context Response"
-    fields_desc = [ PacketListField("IE_list", [], IE_Dispatcher) ]
+    fields_desc = [PacketListField("IE_list", [], IE_Dispatcher)]
+
 
 class GTPPDUNotificationRequest(Packet):
     # 3GPP TS 29.060 V9.1.0 (2009-12)
     name = "GTP PDU Notification Request"
-    fields_desc = [ PacketListField("IE_list", [ IE_IMSI(),
-                        IE_TEICP(TEICI=RandInt()),
-                        IE_EndUserAddress(PDPTypeNumber=0x21),
-                        IE_AccessPointName(),
-                        IE_GSNAddress(address="127.0.0.1"),
-                        ], IE_Dispatcher) ]
+    fields_desc = [PacketListField("IE_list", [IE_IMSI(),
+                                               IE_TEICP(TEICI=RandInt()),
+                                               IE_EndUserAddress(PDPTypeNumber=0x21),  # noqa: E501
+                                               IE_AccessPointName(),
+                                               IE_GSNAddress(address="127.0.0.1"),  # noqa: E501
+                                               ], IE_Dispatcher)]
+
 
 class GTPSupportedExtensionHeadersNotification(Packet):
     name = "GTP Supported Extension Headers Notification"
-    fields_desc = [ PacketListField("IE_list", [ IE_ExtensionHeaderList(),
-                        ], IE_Dispatcher) ]
+    fields_desc = [PacketListField("IE_list", [IE_ExtensionHeaderList(),
+                                               ], IE_Dispatcher)]
+
 
-class GTPErrorIndication(Packet):
-    name = "GTP Error Indication"
-    fields_desc = [ PacketListField("IE_list", [], IE_Dispatcher) ]
-    
 class GTPmorethan1500(Packet):
     # 3GPP TS 29.060 V9.1.0 (2009-12)
     name = "GTP More than 1500"
-    fields_desc = [ ByteEnumField("IE_Cause", "Cause", IEType),
-                    BitField("IE", 1, 12000),]
+    fields_desc = [ByteEnumField("IE_Cause", "Cause", IEType),
+                   BitField("IE", 1, 12000), ]
+
 
 # Bind GTP-C
-bind_layers(UDP, GTPHeader, dport = 2123)
-bind_layers(UDP, GTPHeader, sport = 2123)
+bind_layers(UDP, GTPHeader, dport=2123)
+bind_layers(UDP, GTPHeader, sport=2123)
 bind_layers(GTPHeader, GTPEchoRequest, gtp_type=1, S=1)
 bind_layers(GTPHeader, GTPEchoResponse, gtp_type=2, S=1)
 bind_layers(GTPHeader, GTPCreatePDPContextRequest, gtp_type=16)
@@ -877,16 +898,12 @@ bind_layers(GTPHeader, GTPUpdatePDPContextResponse, gtp_type=19)
 bind_layers(GTPHeader, GTPDeletePDPContextRequest, gtp_type=20)
 bind_layers(GTPHeader, GTPDeletePDPContextResponse, gtp_type=21)
 bind_layers(GTPHeader, GTPPDUNotificationRequest, gtp_type=27)
-bind_layers(GTPHeader, GTPSupportedExtensionHeadersNotification, gtp_type=31, S=1)
+bind_layers(GTPHeader, GTPSupportedExtensionHeadersNotification, gtp_type=31, S=1)  # noqa: E501
 bind_layers(GTPHeader, GTP_UDPPort_ExtensionHeader, next_ex=64, E=1)
 bind_layers(GTPHeader, GTP_PDCP_PDU_ExtensionHeader, next_ex=192, E=1)
 
 # Bind GTP-U
-bind_layers(UDP, GTP_U_Header, dport = 2152)
-bind_layers(UDP, GTP_U_Header, sport = 2152)
+bind_layers(UDP, GTP_U_Header, dport=2152)
+bind_layers(UDP, GTP_U_Header, sport=2152)
 bind_layers(GTP_U_Header, GTPErrorIndication, gtp_type=26, S=1)
-bind_layers(GTP_U_Header, IP, gtp_type = 255)
-
-if __name__ == "__main__":
-    from scapy.all import *
-    interact(mydict=globals(), mybanner="GTPv1 add-on")
+bind_layers(GTP_U_Header, IP, gtp_type=255)
