@@ -1,6 +1,6 @@
 #! /usr/bin/env python2
 #
-# scapy.contrib.description = LLDP
+# scapy.contrib.description = Link Layer Discovery Protocol (LLDP)
 # scapy.contrib.status = loads
 
 """
@@ -28,7 +28,7 @@
             - IEEE 802.1AB 2016 - LLDP protocol, topology and MIB description
 
     :TODO:
-        - organization specific TLV e.g. ProfiNet (see LLDPDUGenericOrganisationSpecific for a starting point)
+        - organization specific TLV e.g. ProfiNet (see LLDPDUGenericOrganisationSpecific for a starting point)  # noqa: E501
 
     :NOTES:
         - you can find the layer configuration options at the end of this file
@@ -45,11 +45,12 @@ from scapy.config import conf
 from scapy.error import log_runtime, Scapy_Exception
 from scapy.layers.l2 import Ether, Dot1Q
 from scapy.fields import MACField, IPField, BitField, \
-         StrLenField, ByteEnumField, BitEnumField, \
-         EnumField, ThreeBytesField, BitFieldLenField, \
-         ShortField, XStrLenField
-from scapy.packet import Packet, Padding, bind_layers
+    StrLenField, ByteEnumField, BitEnumField, \
+    EnumField, ThreeBytesField, BitFieldLenField, \
+    ShortField, XStrLenField, ByteField
+from scapy.packet import Packet, bind_layers
 from scapy.modules.six.moves import range
+import scapy.modules.six as six
 from scapy.data import ETHER_TYPES
 from scapy.compat import orb
 
@@ -152,7 +153,7 @@ class LLDPDU(Packet):
 
         last_layer = not pay
         if last_layer and conf.contribs['LLDP'].strict_mode() and \
-                        type(self).__name__ != LLDPDUEndOfLLDPDU.__name__:
+                type(self).__name__ != LLDPDUEndOfLLDPDU.__name__:
             raise LLDPInvalidLastLayerException('Last layer must be instance '
                                                 'of LLDPDUEndOfLLDPDU - '
                                                 'got {}'.
@@ -181,7 +182,7 @@ class LLDPDU(Packet):
         frame_size += LLDPDU.ETHER_HEADER_LEN
         frame_size += len(pkt) + len(pay) + LLDPDU.ETHER_FSC_LEN
         if frame_size < LLDPDU.ETHER_FRAME_MIN_LEN:
-            return pkt + pay + b'\x00' * (LLDPDU.ETHER_FRAME_MIN_LEN - frame_size)
+            return pkt + pay + b'\x00' * (LLDPDU.ETHER_FRAME_MIN_LEN - frame_size)  # noqa: E501
         return pkt + pay
 
     @staticmethod
@@ -296,6 +297,7 @@ class LLDPDU(Packet):
         self._check()
         return super(LLDPDU, self).do_build()
 
+
 class _LLDPidField(StrLenField):
     """Class that selects the type of the ID field depending
     on the type of `subtype`"""
@@ -309,7 +311,7 @@ class _LLDPidField(StrLenField):
         cls = self.subtypes_dict.get(pkt.subtype, StrLenField)
         try:
             return (cls.m2i.__func__ if six.PY2 else cls.m2i)(self, pkt, x)
-        except:
+        except Exception:
             log_runtime.exception("Failed to dissect " + self.name + " ! ")
             return StrLenField.m2i(self, pkt, x)
 
@@ -317,16 +319,18 @@ class _LLDPidField(StrLenField):
         cls = self.subtypes_dict.get(pkt.subtype, StrLenField)
         try:
             return (cls.i2m.__func__ if six.PY2 else cls.i2m)(self, pkt, x)
-        except:
+        except Exception:
             log_runtime.exception("Failed to build " + self.name + " ! ")
             return StrLenField.i2m(self, pkt, x)
 
+
 def _ldp_id_adjustlen(pkt, x):
     """Return the length of the `id` field,
     according to its real encoded type"""
     f, v = pkt.getfield_and_val('id')
     return len(_LLDPidField.i2m(f, pkt, v)) + 1
 
+
 class LLDPDUChassisID(LLDPDU):
     """
         ieee 802.1ab-2016 - sec. 8.5.2 / p. 26
@@ -362,7 +366,7 @@ class LLDPDUChassisID(LLDPDU):
         BitFieldLenField('_length', None, 9, length_of='id',
                          adjust=lambda pkt, x: _ldp_id_adjustlen(pkt, x)),
         ByteEnumField('subtype', 0x00, LLDP_CHASSIS_ID_TLV_SUBTYPES),
-        _LLDPidField('id', '', LLDP_CHASSIS_ID_TLV_SUBTYPES_FIELDS, length_from=lambda pkt: pkt._length - 1)
+        _LLDPidField('id', '', LLDP_CHASSIS_ID_TLV_SUBTYPES_FIELDS, length_from=lambda pkt: pkt._length - 1)  # noqa: E501
     ]
 
     def _check(self):
@@ -389,7 +393,7 @@ class LLDPDUPortID(LLDPDU):
         range(0x08, 0xff): 'reserved'
     }
 
-    LLDP_PORT_ID_TLV_SUBTYPES = {
+    LLDP_PORT_ID_TLV_SUBTYPES_FIELDS = {
         0x03: MACField,
         0x04: IPField,
     }
@@ -408,7 +412,7 @@ class LLDPDUPortID(LLDPDU):
         BitFieldLenField('_length', None, 9, length_of='id',
                          adjust=lambda pkt, x: _ldp_id_adjustlen(pkt, x)),
         ByteEnumField('subtype', 0x00, LLDP_PORT_ID_TLV_SUBTYPES),
-        _LLDPidField('id', '', LLDP_PORT_ID_TLV_SUBTYPES, length_from=lambda pkt: pkt._length - 1)
+        _LLDPidField('id', '', LLDP_PORT_ID_TLV_SUBTYPES_FIELDS, length_from=lambda pkt: pkt._length - 1)  # noqa: E501
     ]
 
     def _check(self):
@@ -437,6 +441,7 @@ class LLDPDUTimeToLive(LLDPDU):
             raise LLDPInvalidLengthField('length must be 2 - got '
                                          '{}'.format(self._length))
 
+
 class LLDPDUEndOfLLDPDU(LLDPDU):
     """
         ieee 802.1ab-2016 - sec. 8.5.1 / p. 26
@@ -646,7 +651,7 @@ class LLDPDUManagementAddress(LLDPDU):
                          8 + len(pkt.management_address) + len(pkt.object_id)),
         BitFieldLenField('_management_address_string_length', None, 8,
                          length_of='management_address',
-                         adjust=lambda pkt, x: len(pkt.management_address) + 1),
+                         adjust=lambda pkt, x: len(pkt.management_address) + 1),  # noqa: E501
         ByteEnumField('management_address_subtype', 0x00,
                       IANA_ADDRESS_FAMILY_NUMBERS),
         XStrLenField('management_address', '',
@@ -691,19 +696,20 @@ class LLDPDUGenericOrganisationSpecific(LLDPDU):
         ORG_UNIQUE_CODE_PNO: "PROFIBUS International (PNO)",
         ORG_UNIQUE_CODE_IEEE_802_1: "IEEE 802.1",
         ORG_UNIQUE_CODE_IEEE_802_3: "IEEE 802.3",
-        ORG_UNIQUE_CODE_TIA_TR_41_MED: "TIA TR-41 Committee . Media Endpoint Discovery",
+        ORG_UNIQUE_CODE_TIA_TR_41_MED: "TIA TR-41 Committee . Media Endpoint Discovery",  # noqa: E501
         ORG_UNIQUE_CODE_HYTEC: "Hytec Geraetebau GmbH"
     }
 
     fields_desc = [
         BitEnumField('_type', 127, 7, LLDPDU.TYPES),
-        BitFieldLenField('_length', None, 9, length_of='data', adjust=lambda pkt, x: len(pkt.data) + 4),
+        BitFieldLenField('_length', None, 9, length_of='data', adjust=lambda pkt, x: len(pkt.data) + 4),  # noqa: E501
         ThreeBytesEnumField('org_code', 0, ORG_UNIQUE_CODES),
         ByteField('subtype', 0x00),
         XStrLenField('data', '', length_from=lambda pkt: pkt._length - 4)
     ]
 
-# 0x09 .. 0x7e is reserved for future standardization and for now treated as Raw() data
+
+# 0x09 .. 0x7e is reserved for future standardization and for now treated as Raw() data  # noqa: E501
 LLDPDU_CLASS_TYPES = {
     0x00: LLDPDUEndOfLLDPDU,
     0x01: LLDPDUChassisID,
@@ -717,10 +723,12 @@ LLDPDU_CLASS_TYPES = {
     127: LLDPDUGenericOrganisationSpecific
 }
 
+
 class LLDPConfiguration(object):
     """
     basic configuration for LLDP layer
     """
+
     def __init__(self):
         self._strict_mode = True
         self.strict_mode_enable()
