@@ -1,6 +1,6 @@
 #!/usr/bin/env python2
 
-# scapy.contrib.description = OSPF
+# scapy.contrib.description = Open Shortest Path First (OSPF)
 # scapy.contrib.status = loads
 
 # This file is part of Scapy
@@ -28,11 +28,19 @@ Copyright (c) 2010 Jochen Bartl  :  jochen.bartl gmail com
 """
 
 
-from scapy.packet import *
-from scapy.fields import *
-from scapy.layers.inet import *
-from scapy.layers.inet6 import *
+import struct
+
+from scapy.packet import bind_layers, Packet
+from scapy.fields import BitField, ByteEnumField, ByteField, \
+    ConditionalField, DestIP6Field, FieldLenField, \
+    FieldListField, FlagsField, IP6Field, IP6PrefixField, IPField, \
+    IntEnumField, IntField, LenField, PacketListField, ShortEnumField, \
+    ShortField, StrLenField, X3BytesField, XIntField, XLongField, XShortField
+from scapy.layers.inet import IP, DestIPField
+from scapy.layers.inet6 import IPv6, in6_chksum
+from scapy.utils import fletcher16_checkbytes, checksum
 from scapy.compat import orb
+from scapy.config import conf
 
 EXT_VERSION = "v0.9.2"
 
@@ -58,6 +66,7 @@ class _NoLLSLenField(LenField):
     LenField that will ignore the size of OSPF_LLS_Hdr if it exists
     in the payload
     """
+
     def i2m(self, pkt, x):
         if x is None:
             x = self.adjust(len(pkt.payload))
@@ -65,25 +74,26 @@ class _NoLLSLenField(LenField):
             x -= len(pkt[OSPF_LLS_Hdr])
         return x
 
+
 class OSPF_Hdr(Packet):
     name = "OSPF Header"
     fields_desc = [
-                    ByteField("version", 2),
-                    ByteEnumField("type", 1, _OSPF_types),
-                    _NoLLSLenField("len", None, adjust=lambda x: x+24),
-                    IPField("src", "1.1.1.1"),
-                    IPField("area", "0.0.0.0"), # default: backbone
-                    XShortField("chksum", None),
-                    ShortEnumField("authtype", 0, {0:"Null", 1:"Simple", 2:"Crypto"}),
-                    # Null or Simple Authentication
-                    ConditionalField(XLongField("authdata", 0), lambda pkt:pkt.authtype != 2),
-                    # Crypto Authentication
-                    ConditionalField(XShortField("reserved", 0), lambda pkt:pkt.authtype == 2),
-                    ConditionalField(ByteField("keyid", 1), lambda pkt:pkt.authtype == 2),
-                    ConditionalField(ByteField("authdatalen", 0), lambda pkt:pkt.authtype == 2),
-                    ConditionalField(XIntField("seq", 0), lambda pkt:pkt.authtype == 2),
-                    # TODO: Support authdata (which is appended to the packets as if it were padding)
-                    ]
+        ByteField("version", 2),
+        ByteEnumField("type", 1, _OSPF_types),
+        _NoLLSLenField("len", None, adjust=lambda x: x + 24),
+        IPField("src", "1.1.1.1"),
+        IPField("area", "0.0.0.0"),  # default: backbone
+        XShortField("chksum", None),
+        ShortEnumField("authtype", 0, {0: "Null", 1: "Simple", 2: "Crypto"}),
+        # Null or Simple Authentication
+        ConditionalField(XLongField("authdata", 0), lambda pkt: pkt.authtype != 2),  # noqa: E501
+        # Crypto Authentication
+        ConditionalField(XShortField("reserved", 0), lambda pkt: pkt.authtype == 2),  # noqa: E501
+        ConditionalField(ByteField("keyid", 1), lambda pkt: pkt.authtype == 2),
+        ConditionalField(ByteField("authdatalen", 0), lambda pkt: pkt.authtype == 2),  # noqa: E501
+        ConditionalField(XIntField("seq", 0), lambda pkt: pkt.authtype == 2),
+        # TODO: Support authdata (which is appended to the packets as if it were padding)  # noqa: E501
+    ]
 
     def post_build(self, p, pay):
         # See <http://tools.ietf.org/html/rfc5613>
@@ -105,8 +115,8 @@ class OSPF_Hdr(Packet):
     def answers(self, other):
         if (isinstance(other, OSPF_Hdr) and
             self.area == other.area and
-            self.type == 5):  # Only acknowledgements answer other packets
-                return self.payload.answers(other.payload)
+                self.type == 5):  # Only acknowledgements answer other packets
+            return self.payload.answers(other.payload)
         return 0
 
 
@@ -119,7 +129,7 @@ class OSPF_Hello(Packet):
                    IntField("deadinterval", 40),
                    IPField("router", "0.0.0.0"),
                    IPField("backup", "0.0.0.0"),
-                   FieldListField("neighbors", [], IPField("", "0.0.0.0"), length_from=lambda pkt: (pkt.underlayer.len - 44) if pkt.underlayer else None)]
+                   FieldListField("neighbors", [], IPField("", "0.0.0.0"), length_from=lambda pkt: (pkt.underlayer.len - 44) if pkt.underlayer else None)]  # noqa: E501
 
     def guess_payload_class(self, payload):
         # check presence of LLS data block flag
@@ -138,19 +148,22 @@ class LLS_Generic_TLV(Packet):
     def guess_payload_class(self, p):
         return conf.padding_layer
 
+
 class LLS_Extended_Options(LLS_Generic_TLV):
     name = "LLS Extended Options and Flags"
     fields_desc = [ShortField("type", 1),
                    FieldLenField("len", None, fmt="!H", length_of="options"),
                    StrLenField("options", "", length_from=lambda x: x.len)]
-                 # TODO: FlagsField("options", 0, names=["LR", "RS"], size) with dynamic size
+    # TODO: FlagsField("options", 0, names=["LR", "RS"], size) with dynamic size  # noqa: E501
+
 
 class LLS_Crypto_Auth(LLS_Generic_TLV):
     name = "LLS Cryptographic Authentication"
     fields_desc = [ShortField("type", 2),
-                   FieldLenField("len", 20, fmt="B", length_of=lambda x: x.authdata + 4),
+                   FieldLenField("len", 20, fmt="B", length_of=lambda x: x.authdata + 4),  # noqa: E501
                    XIntField("sequence", 0),
-                   StrLenField("authdata", b"\x00" * 16, length_from=lambda x: x.len - 4)]
+                   StrLenField("authdata", b"\x00" * 16, length_from=lambda x: x.len - 4)]  # noqa: E501
+
 
 _OSPF_LLSclasses = {1: "LLS_Extended_Options",
                     2: "LLS_Crypto_Auth"}
@@ -166,15 +179,17 @@ def _LLSGuessPayloadClass(p, **kargs):
         cls = globals()[clsname]
     return cls(p, **kargs)
 
+
 class FieldLenField32Bits(FieldLenField):
     def i2repr(self, pkt, x):
-        return repr(x) if not x else str(FieldLenField.i2h(self, pkt, x) << 2) + " bytes"
+        return repr(x) if not x else str(FieldLenField.i2h(self, pkt, x) << 2) + " bytes"  # noqa: E501
+
 
 class OSPF_LLS_Hdr(Packet):
     name = "OSPF Link-local signaling"
     fields_desc = [XShortField("chksum", None),
-                   FieldLenField32Bits("len", None, length_of="llstlv", adjust=lambda pkt, x: (x + 4) >> 2),
-                   PacketListField("llstlv", [], _LLSGuessPayloadClass, length_from=lambda x: (x.len << 2) - 4)]
+                   FieldLenField32Bits("len", None, length_of="llstlv", adjust=lambda pkt, x: (x + 4) >> 2),  # noqa: E501
+                   PacketListField("llstlv", [], _LLSGuessPayloadClass, length_from=lambda x: (x.len << 2) - 4)]  # noqa: E501
 
     def post_build(self, p, pay):
         p += pay
@@ -183,6 +198,7 @@ class OSPF_LLS_Hdr(Packet):
             p = struct.pack("!H", c) + p[2:]
         return p
 
+
 _OSPF_LStypes = {1: "router",
                  2: "network",
                  3: "summaryIP",
@@ -199,7 +215,7 @@ _OSPF_LSclasses = {1: "OSPF_Router_LSA",
 
 
 def ospf_lsa_checksum(lsa):
-    return fletcher16_checkbytes(b"\x00\x00" + lsa[2:], 16) # leave out age
+    return fletcher16_checkbytes(b"\x00\x00" + lsa[2:], 16)  # leave out age
 
 
 class OSPF_LSA_Hdr(Packet):
@@ -232,8 +248,8 @@ class OSPF_Link(Packet):
                    ShortField("metric", 10),
                    # TODO: define correct conditions
                    ConditionalField(ByteField("tos", 0), lambda pkt: False),
-                   ConditionalField(ByteField("reserved", 0), lambda pkt: False),
-                   ConditionalField(ShortField("tosmetric", 0), lambda pkt: False)]
+                   ConditionalField(ByteField("reserved", 0), lambda pkt: False),  # noqa: E501
+                   ConditionalField(ShortField("tosmetric", 0), lambda pkt: False)]  # noqa: E501
 
     def extract_padding(self, s):
         return "", s
@@ -241,8 +257,8 @@ class OSPF_Link(Packet):
 
 def _LSAGuessPayloadClass(p, **kargs):
     """ Guess the correct LSA class for a given payload """
-    # This is heavily based on scapy-cdp.py by Nicolas Bareil and Arnaud Ebalard
-    
+    # This is heavily based on scapy-cdp.py by Nicolas Bareil and Arnaud Ebalard  # noqa: E501
+
     cls = conf.raw_layer
     if len(p) >= 4:
         typ = orb(p[3])
@@ -265,7 +281,6 @@ class OSPF_BaseLSA(Packet):
         return p    # p+pay?
 
     def extract_padding(self, s):
-        length = self.len
         return "", s
 
 
@@ -283,8 +298,8 @@ class OSPF_Router_LSA(OSPF_BaseLSA):
                    ByteField("reserved", 0),
                    FieldLenField("linkcount", None, count_of="linklist"),
                    PacketListField("linklist", [], OSPF_Link,
-                                     count_from=lambda pkt: pkt.linkcount,
-                                     length_from=lambda pkt: pkt.linkcount * 12)]
+                                   count_from=lambda pkt: pkt.linkcount,
+                                   length_from=lambda pkt: pkt.linkcount * 12)]
 
 
 class OSPF_Network_LSA(OSPF_BaseLSA):
@@ -299,7 +314,7 @@ class OSPF_Network_LSA(OSPF_BaseLSA):
                    ShortField("len", None),
                    IPField("mask", "255.255.255.0"),
                    FieldListField("routerlist", [], IPField("", "1.1.1.1"),
-                                    length_from=lambda pkt: pkt.len - 24)]
+                                  length_from=lambda pkt: pkt.len - 24)]
 
 
 class OSPF_SummaryIP_LSA(OSPF_BaseLSA):
@@ -317,7 +332,7 @@ class OSPF_SummaryIP_LSA(OSPF_BaseLSA):
                    X3BytesField("metric", 10),
                    # TODO: Define correct conditions
                    ConditionalField(ByteField("tos", 0), lambda pkt:False),
-                   ConditionalField(X3BytesField("tosmetric", 0), lambda pkt:False)]
+                   ConditionalField(X3BytesField("tosmetric", 0), lambda pkt:False)]  # noqa: E501
 
 
 class OSPF_SummaryASBR_LSA(OSPF_SummaryIP_LSA):
@@ -346,7 +361,7 @@ class OSPF_External_LSA(OSPF_BaseLSA):
                    XIntField("tag", 0),
                    # TODO: Define correct conditions
                    ConditionalField(ByteField("tos", 0), lambda pkt:False),
-                   ConditionalField(X3BytesField("tosmetric", 0), lambda pkt:False)]
+                   ConditionalField(X3BytesField("tosmetric", 0), lambda pkt:False)]  # noqa: E501
 
 
 class OSPF_NSSA_External_LSA(OSPF_External_LSA):
@@ -358,11 +373,11 @@ class OSPF_DBDesc(Packet):
     name = "OSPF Database Description"
     fields_desc = [ShortField("mtu", 1500),
                    OSPFOptionsField(),
-                   FlagsField("dbdescr", 0, 8, ["MS", "M", "I", "R", "4", "3", "2", "1"]),
+                   FlagsField("dbdescr", 0, 8, ["MS", "M", "I", "R", "4", "3", "2", "1"]),  # noqa: E501
                    IntField("ddseq", 1),
                    PacketListField("lsaheaders", None, OSPF_LSA_Hdr,
-                                    count_from = lambda pkt: None,
-                                    length_from = lambda pkt: pkt.underlayer.len - 24 - 8)]
+                                   count_from=lambda pkt: None,
+                                   length_from=lambda pkt: pkt.underlayer.len - 24 - 8)]  # noqa: E501
 
     def guess_payload_class(self, payload):
         # check presence of LLS data block flag
@@ -385,37 +400,37 @@ class OSPF_LSReq_Item(Packet):
 class OSPF_LSReq(Packet):
     name = "OSPF Link State Request (container)"
     fields_desc = [PacketListField("requests", None, OSPF_LSReq_Item,
-                                  count_from = lambda pkt:None,
-                                  length_from = lambda pkt:pkt.underlayer.len - 24)]
+                                   count_from=lambda pkt:None,
+                                   length_from=lambda pkt:pkt.underlayer.len - 24)]  # noqa: E501
 
 
 class OSPF_LSUpd(Packet):
     name = "OSPF Link State Update"
-    fields_desc = [FieldLenField("lsacount", None, fmt="!I", count_of="lsalist"),
+    fields_desc = [FieldLenField("lsacount", None, fmt="!I", count_of="lsalist"),  # noqa: E501
                    PacketListField("lsalist", None, _LSAGuessPayloadClass,
-                                count_from = lambda pkt: pkt.lsacount,
-                                length_from = lambda pkt: pkt.underlayer.len - 24)]
+                                   count_from=lambda pkt: pkt.lsacount,
+                                   length_from=lambda pkt: pkt.underlayer.len - 24)]  # noqa: E501
 
 
 class OSPF_LSAck(Packet):
     name = "OSPF Link State Acknowledgement"
     fields_desc = [PacketListField("lsaheaders", None, OSPF_LSA_Hdr,
-                                   count_from = lambda pkt: None,
-                                   length_from = lambda pkt: pkt.underlayer.len - 24)]
+                                   count_from=lambda pkt: None,
+                                   length_from=lambda pkt: pkt.underlayer.len - 24)]  # noqa: E501
 
     def answers(self, other):
         if isinstance(other, OSPF_LSUpd):
             for reqLSA in other.lsalist:
                 for ackLSA in self.lsaheaders:
                     if (reqLSA.type == ackLSA.type and
-                        reqLSA.seq == ackLSA.seq):
+                            reqLSA.seq == ackLSA.seq):
                         return 1
         return 0
 
 
-#------------------------------------------------------------------------------
+###############################################################################
 # OSPFv3
-#------------------------------------------------------------------------------
+###############################################################################
 class OSPFv3_Hdr(Packet):
     name = "OSPFv3 Header"
     fields_desc = [ByteField("version", 3),
@@ -429,11 +444,11 @@ class OSPFv3_Hdr(Packet):
 
     def post_build(self, p, pay):
         p += pay
-        l = self.len
+        tmp_len = self.len
 
-        if l is None:
-            l = len(p)
-            p = p[:2] + struct.pack("!H", l) + p[4:]
+        if tmp_len is None:
+            tmp_len = len(p)
+            p = p[:2] + struct.pack("!H", tmp_len) + p[4:]
 
         if self.chksum is None:
             chksum = in6_chksum(89, self.underlayer, p)
@@ -461,7 +476,7 @@ class OSPFv3_Hello(Packet):
                    IPField("router", "0.0.0.0"),
                    IPField("backup", "0.0.0.0"),
                    FieldListField("neighbors", [], IPField("", "0.0.0.0"),
-                                    length_from=lambda pkt: (pkt.underlayer.len - 36))]
+                                  length_from=lambda pkt: (pkt.underlayer.len - 36))]  # noqa: E501
 
 
 _OSPFv3_LStypes = {0x2001: "router",
@@ -541,7 +556,7 @@ class OSPFv3_Router_LSA(OSPF_BaseLSA):
                    FlagsField("flags", 0, 8, ["B", "E", "V", "W"]),
                    OSPFv3OptionsField(),
                    PacketListField("linklist", [], OSPFv3_Link,
-                                     length_from=lambda pkt:pkt.len - 24)]
+                                   length_from=lambda pkt:pkt.len - 24)]
 
 
 class OSPFv3_Network_LSA(OSPF_BaseLSA):
@@ -556,7 +571,7 @@ class OSPFv3_Network_LSA(OSPF_BaseLSA):
                    ByteField("reserved", 0),
                    OSPFv3OptionsField(),
                    FieldListField("routerlist", [], IPField("", "0.0.0.1"),
-                                    length_from=lambda pkt: pkt.len - 24)]
+                                  length_from=lambda pkt: pkt.len - 24)]
 
 
 class OSPFv3PrefixOptionsField(FlagsField):
@@ -579,10 +594,10 @@ class OSPFv3_Inter_Area_Prefix_LSA(OSPF_BaseLSA):
                    ShortField("len", None),
                    ByteField("reserved", 0),
                    X3BytesField("metric", 10),
-                   FieldLenField("prefixlen", None, length_of="prefix", fmt="B"),
+                   FieldLenField("prefixlen", None, length_of="prefix", fmt="B"),  # noqa: E501
                    OSPFv3PrefixOptionsField(),
                    ShortField("reserved2", 0),
-                   IP6PrefixField("prefix", "2001:db8:0:42::/64", wordbytes=4, length_from=lambda pkt: pkt.prefixlen)]
+                   IP6PrefixField("prefix", "2001:db8:0:42::/64", wordbytes=4, length_from=lambda pkt: pkt.prefixlen)]  # noqa: E501
 
 
 class OSPFv3_Inter_Area_Router_LSA(OSPF_BaseLSA):
@@ -612,13 +627,13 @@ class OSPFv3_AS_External_LSA(OSPF_BaseLSA):
                    ShortField("len", None),
                    FlagsField("flags", 0, 8, ["T", "F", "E"]),
                    X3BytesField("metric", 20),
-                   FieldLenField("prefixlen", None, length_of="prefix", fmt="B"),
+                   FieldLenField("prefixlen", None, length_of="prefix", fmt="B"),  # noqa: E501
                    OSPFv3PrefixOptionsField(),
                    ShortEnumField("reflstype", 0, _OSPFv3_LStypes),
-                   IP6PrefixField("prefix", "2001:db8:0:42::/64", wordbytes=4, length_from=lambda pkt: pkt.prefixlen),
-                   ConditionalField(IP6Field("fwaddr", "::"), lambda pkt: pkt.flags & 0x02 == 0x02),
-                   ConditionalField(IntField("tag", 0), lambda pkt: pkt.flags & 0x01 == 0x01),
-                   ConditionalField(IPField("reflsid", 0), lambda pkt: pkt.reflstype != 0)]
+                   IP6PrefixField("prefix", "2001:db8:0:42::/64", wordbytes=4, length_from=lambda pkt: pkt.prefixlen),  # noqa: E501
+                   ConditionalField(IP6Field("fwaddr", "::"), lambda pkt: pkt.flags & 0x02 == 0x02),  # noqa: E501
+                   ConditionalField(IntField("tag", 0), lambda pkt: pkt.flags & 0x01 == 0x01),  # noqa: E501
+                   ConditionalField(IPField("reflsid", 0), lambda pkt: pkt.reflstype != 0)]  # noqa: E501
 
 
 class OSPFv3_Type_7_LSA(OSPFv3_AS_External_LSA):
@@ -628,10 +643,10 @@ class OSPFv3_Type_7_LSA(OSPFv3_AS_External_LSA):
 
 class OSPFv3_Prefix_Item(Packet):
     name = "OSPFv3 Link Prefix Item"
-    fields_desc = [FieldLenField("prefixlen", None, length_of="prefix", fmt="B"),
+    fields_desc = [FieldLenField("prefixlen", None, length_of="prefix", fmt="B"),  # noqa: E501
                    OSPFv3PrefixOptionsField(),
                    ShortField("metric", 10),
-                   IP6PrefixField("prefix", "2001:db8:0:42::/64", wordbytes=4, length_from=lambda pkt: pkt.prefixlen)]
+                   IP6PrefixField("prefix", "2001:db8:0:42::/64", wordbytes=4, length_from=lambda pkt: pkt.prefixlen)]  # noqa: E501
 
     def extract_padding(self, s):
         return "", s
@@ -649,9 +664,9 @@ class OSPFv3_Link_LSA(OSPF_BaseLSA):
                    ByteField("prio", 1),
                    OSPFv3OptionsField(),
                    IP6Field("lladdr", "fe80::"),
-                   FieldLenField("prefixes", None, count_of="prefixlist", fmt="I"),
+                   FieldLenField("prefixes", None, count_of="prefixlist", fmt="I"),  # noqa: E501
                    PacketListField("prefixlist", None, OSPFv3_Prefix_Item,
-                                  count_from = lambda pkt: pkt.prefixes)]
+                                   count_from=lambda pkt: pkt.prefixes)]
 
 
 class OSPFv3_Intra_Area_Prefix_LSA(OSPF_BaseLSA):
@@ -663,12 +678,12 @@ class OSPFv3_Intra_Area_Prefix_LSA(OSPF_BaseLSA):
                    XIntField("seq", 0x80000001),
                    XShortField("chksum", None),
                    ShortField("len", None),
-                   FieldLenField("prefixes", None, count_of="prefixlist", fmt="H"),
+                   FieldLenField("prefixes", None, count_of="prefixlist", fmt="H"),  # noqa: E501
                    ShortEnumField("reflstype", 0, _OSPFv3_LStypes),
                    IPField("reflsid", "0.0.0.0"),
                    IPField("refadrouter", "0.0.0.0"),
                    PacketListField("prefixlist", None, OSPFv3_Prefix_Item,
-                                  count_from = lambda pkt: pkt.prefixes)]
+                                   count_from=lambda pkt: pkt.prefixes)]
 
 
 class OSPFv3_DBDesc(Packet):
@@ -680,8 +695,8 @@ class OSPFv3_DBDesc(Packet):
                    FlagsField("dbdescr", 0, 8, ["MS", "M", "I", "R"]),
                    IntField("ddseq", 1),
                    PacketListField("lsaheaders", None, OSPFv3_LSA_Hdr,
-                                    count_from = lambda pkt:None,
-                                    length_from = lambda pkt:pkt.underlayer.len - 28)]
+                                   count_from=lambda pkt:None,
+                                   length_from=lambda pkt:pkt.underlayer.len - 28)]  # noqa: E501
 
 
 class OSPFv3_LSReq_Item(Packet):
@@ -698,23 +713,23 @@ class OSPFv3_LSReq_Item(Packet):
 class OSPFv3_LSReq(Packet):
     name = "OSPFv3 Link State Request (container)"
     fields_desc = [PacketListField("requests", None, OSPFv3_LSReq_Item,
-                                  count_from = lambda pkt:None,
-                                  length_from = lambda pkt:pkt.underlayer.len - 16)]
+                                   count_from=lambda pkt:None,
+                                   length_from=lambda pkt:pkt.underlayer.len - 16)]  # noqa: E501
 
 
 class OSPFv3_LSUpd(Packet):
     name = "OSPFv3 Link State Update"
-    fields_desc = [FieldLenField("lsacount", None, fmt="!I", count_of="lsalist"),
+    fields_desc = [FieldLenField("lsacount", None, fmt="!I", count_of="lsalist"),  # noqa: E501
                    PacketListField("lsalist", [], _OSPFv3_LSAGuessPayloadClass,
-                                count_from = lambda pkt:pkt.lsacount,
-                                length_from = lambda pkt:pkt.underlayer.len - 16)]
+                                   count_from=lambda pkt:pkt.lsacount,
+                                   length_from=lambda pkt:pkt.underlayer.len - 16)]  # noqa: E501
 
 
 class OSPFv3_LSAck(Packet):
     name = "OSPFv3 Link State Acknowledgement"
     fields_desc = [PacketListField("lsaheaders", None, OSPFv3_LSA_Hdr,
-                                   count_from = lambda pkt:None,
-                                   length_from = lambda pkt:pkt.underlayer.len - 16)]
+                                   count_from=lambda pkt:None,
+                                   length_from=lambda pkt:pkt.underlayer.len - 16)]  # noqa: E501
 
 
 bind_layers(IP, OSPF_Hdr, proto=89)
