@@ -1,7 +1,7 @@
-## This file is part of Scapy
-## Copyright (C) 2007, 2008, 2009 Arnaud Ebalard
-##               2015, 2016, 2017 Maxence Tury
-## This program is published under a GPLv2 license
+# This file is part of Scapy
+# Copyright (C) 2007, 2008, 2009 Arnaud Ebalard
+# 2015, 2016, 2017 Maxence Tury
+# This program is published under a GPLv2 license
 
 """
 Common TLS fields & bindings.
@@ -12,13 +12,14 @@ ApplicationData submessages. For the Handshake type, see tls_handshake.py.
 See the TLS class documentation for more information.
 """
 
-import struct, traceback
+import struct
 
 from scapy.config import conf
 from scapy.error import log_runtime
-from scapy.fields import *
-from scapy.compat import *
-from scapy.packet import *
+from scapy.fields import ByteEnumField, PacketListField, StrField
+from scapy.compat import raw, chb, orb
+from scapy.utils import randstring
+from scapy.packet import Raw, Padding, bind_layers
 from scapy.layers.inet import TCP
 from scapy.layers.tls.session import _GenericTLSSessionInheritance
 from scapy.layers.tls.handshake import (_tls_handshake_cls, _TLSHandshake,
@@ -27,26 +28,29 @@ from scapy.layers.tls.basefields import (_TLSVersionField, _tls_version,
                                          _TLSIVField, _TLSMACField,
                                          _TLSPadField, _TLSPadLenField,
                                          _TLSLengthField, _tls_type)
-from scapy.layers.tls.crypto.pkcs1 import randstring, pkcs_i2osp
-from scapy.layers.tls.crypto.compression import Comp_NULL
+from scapy.layers.tls.crypto.pkcs1 import pkcs_i2osp
 from scapy.layers.tls.crypto.cipher_aead import AEADTagError
-if conf.crypto_valid_advanced:
-    from scapy.layers.tls.crypto.cipher_aead import Cipher_CHACHA20_POLY1305
 from scapy.layers.tls.crypto.cipher_stream import Cipher_NULL
 from scapy.layers.tls.crypto.ciphers import CipherError
 from scapy.layers.tls.crypto.h_mac import HMACError
+import scapy.modules.six as six
+if conf.crypto_valid_advanced:
+    from scapy.layers.tls.crypto.cipher_aead import Cipher_CHACHA20_POLY1305
 
 # Util
+
+
 def _tls_version_check(version, min):
     """Returns if version >= min, or False if version == None"""
-    if version == None:
+    if version is None:
         return False
     return version >= min
 
 ###############################################################################
-### TLS Record Protocol                                                     ###
+#   TLS Record Protocol                                                       #
 ###############################################################################
 
+
 class _TLSEncryptedContent(Raw):
     """
     When the content of a TLS record (more precisely, a TLSCiphertext) could
@@ -64,6 +68,7 @@ class _TLSMsgListField(PacketListField):
     multiple sublayer messages (notably, several handshake messages),
     we inherit from PacketListField.
     """
+
     def __init__(self, name, default, length_from=None):
         if not length_from:
             length_from = self._get_length
@@ -97,7 +102,7 @@ class _TLSMsgListField(PacketListField):
         else:
             try:
                 return cls(m, tls_session=pkt.tls_session)
-            except:
+            except Exception:
                 if conf.debug_dissector:
                     raise
                 return Raw(m)
@@ -110,23 +115,23 @@ class _TLSMsgListField(PacketListField):
         notably important for several TLS handshake implementations, which
         may for instance pack a server_hello, a certificate, a
         server_key_exchange and a server_hello_done, all in one record.
-        Each parsed message may update the TLS context throught their method
+        Each parsed message may update the TLS context through their method
         .post_dissection_tls_session_update().
 
         If the decryption failed with a CipherError, presumably because we
         missed the session keys, we signal it by returning a
         _TLSEncryptedContent packet which simply contains the ciphered data.
         """
-        l = self.length_from(pkt)
+        tmp_len = self.length_from(pkt)
         lst = []
         ret = b""
         remain = s
-        if l is not None:
-            remain, ret = s[:l], s[l:]
+        if tmp_len is not None:
+            remain, ret = s[:tmp_len], s[tmp_len:]
 
         if remain == b"":
             if (((pkt.tls_session.tls_version or 0x0303) > 0x0200) and
-                hasattr(pkt, "type") and pkt.type == 23):
+                    hasattr(pkt, "type") and pkt.type == 23):
                 return ret, [TLSApplicationData(data=b"")]
             else:
                 return ret, [Raw(load=b"")]
@@ -154,31 +159,31 @@ class _TLSMsgListField(PacketListField):
             return remain + ret, lst
 
     def i2m(self, pkt, p):
-       """
-       Update the context with information from the built packet.
-       If no type was given at the record layer, we try to infer it.
-       """
-       cur = b""
-       if isinstance(p, _GenericTLSSessionInheritance):
-           if pkt.type is None:
-               if isinstance(p, TLSChangeCipherSpec):
-                   pkt.type = 20
-               elif isinstance(p, TLSAlert):
-                   pkt.type = 21
-               elif isinstance(p, _TLSHandshake):
-                   pkt.type = 22
-               elif isinstance(p, TLSApplicationData):
-                   pkt.type = 23
-           p.tls_session = pkt.tls_session
-           if not pkt.tls_session.frozen:
-               cur = p.raw_stateful()
-               p.post_build_tls_session_update(cur)
-           else:
-               cur = raw(p)
-       else:
-           pkt.type = 23
-           cur = raw(p)
-       return cur
+        """
+        Update the context with information from the built packet.
+        If no type was given at the record layer, we try to infer it.
+        """
+        cur = b""
+        if isinstance(p, _GenericTLSSessionInheritance):
+            if pkt.type is None:
+                if isinstance(p, TLSChangeCipherSpec):
+                    pkt.type = 20
+                elif isinstance(p, TLSAlert):
+                    pkt.type = 21
+                elif isinstance(p, _TLSHandshake):
+                    pkt.type = 22
+                elif isinstance(p, TLSApplicationData):
+                    pkt.type = 23
+            p.tls_session = pkt.tls_session
+            if not pkt.tls_session.frozen:
+                cur = p.raw_stateful()
+                p.post_build_tls_session_update(cur)
+            else:
+                cur = raw(p)
+        else:
+            pkt.type = 23
+            cur = raw(p)
+        return cur
 
     def addfield(self, pkt, s, val):
         """
@@ -190,8 +195,8 @@ class _TLSMsgListField(PacketListField):
             res += self.i2m(pkt, p)
         if (isinstance(pkt, _GenericTLSSessionInheritance) and
             _tls_version_check(pkt.tls_session.tls_version, 0x0304) and
-            not isinstance(pkt, TLS13ServerHello)):
-                return s + res
+                not isinstance(pkt, TLS13ServerHello)):
+            return s + res
         if not pkt.type:
             pkt.type = 0
         hdr = struct.pack("!B", pkt.type) + s[1:5]
@@ -236,7 +241,7 @@ class TLS(_GenericTLSSessionInheritance):
     will not be able to verify the signature of the server_key_exchange inside
     t2. However, it should be able to do so for t3, thanks to the tls_session.
     The consequence of not having a complete TLS context is even more obvious
-    when trying to parse ciphered content, as we decribed before.
+    when trying to parse ciphered content, as we described before.
 
     Thus, in order to parse TLS-protected communications with Scapy:
     _either Scapy reads every message from one side of the TLS connection and
@@ -254,14 +259,14 @@ class TLS(_GenericTLSSessionInheritance):
     """
     __slots__ = ["deciphered_len"]
     name = "TLS"
-    fields_desc = [ ByteEnumField("type", None, _tls_type),
-                    _TLSVersionField("version", None, _tls_version),
-                    _TLSLengthField("len", None),
-                    _TLSIVField("iv", None),
-                    _TLSMsgListField("msg", []),
-                    _TLSMACField("mac", None),
-                    _TLSPadField("pad", None),
-                    _TLSPadLenField("padlen", None) ]
+    fields_desc = [ByteEnumField("type", None, _tls_type),
+                   _TLSVersionField("version", None, _tls_version),
+                   _TLSLengthField("len", None),
+                   _TLSIVField("iv", None),
+                   _TLSMsgListField("msg", []),
+                   _TLSMACField("mac", None),
+                   _TLSPadField("pad", None),
+                   _TLSPadLenField("padlen", None)]
 
     def __init__(self, *args, **kargs):
         self.deciphered_len = kargs.get("deciphered_len", None)
@@ -289,13 +294,13 @@ class TLS(_GenericTLSSessionInheritance):
                         from scapy.layers.tls.record_tls13 import TLS13
                         return TLS13
         if _pkt and len(_pkt) < 5:
-                # Layer detected as TLS but too small to be a real packet (len<5).
-                # Those packets appear when sessions are interrupted or to flush buffers.
+                # Layer detected as TLS but too small to be a real packet (len<5).  # noqa: E501
+                # Those packets appear when sessions are interrupted or to flush buffers.  # noqa: E501
                 # Scapy should not try to decode them
             return conf.raw_layer
         return TLS
 
-    ### Parsing methods
+    # Parsing methods
 
     def _tls_auth_decrypt(self, hdr, s):
         """
@@ -318,7 +323,7 @@ class TLS(_GenericTLSSessionInheritance):
             return e.args
         except AEADTagError as e:
             pkt_info = self.firstlayer().summary()
-            log_runtime.info("TLS: record integrity check failed [%s]", pkt_info)
+            log_runtime.info("TLS: record integrity check failed [%s]", pkt_info)  # noqa: E501
             return e.args
 
     def _tls_decrypt(self, s):
@@ -384,7 +389,7 @@ class TLS(_GenericTLSSessionInheritance):
             raise Exception("Invalid record: header is too short.")
 
         msglen = struct.unpack('!H', s[3:5])[0]
-        hdr, efrag, r = s[:5], s[5:5+msglen], s[msglen+5:]
+        hdr, efrag, r = s[:5], s[5:5 + msglen], s[msglen + 5:]
 
         iv = mac = pad = b""
         self.padlen = None
@@ -415,9 +420,9 @@ class TLS(_GenericTLSSessionInheritance):
                 # but the result is the same as with TLS 1.2 anyway.
                 # This leading *IV* has been decrypted by _tls_decrypt with a
                 # random IV, hence it does not correspond to anything.
-                # What actually matters is that we got the first encrypted block
+                # What actually matters is that we got the first encrypted block  # noqa: E501
                 # in order to decrypt the second block (first data block).
-                #if version >= 0x0302:
+                # if version >= 0x0302:
                 #    block_size = self.tls_session.rcs.cipher.block_size
                 #    iv, pfrag = pfrag[:block_size], pfrag[block_size:]
                 #    l = struct.unpack('!H', hdr[3:5])[0]
@@ -429,9 +434,9 @@ class TLS(_GenericTLSSessionInheritance):
                 self.padlen = padlen
 
                 # Extract MAC
-                l = self.tls_session.rcs.mac_len
-                if l != 0:
-                    cfrag, mac = mfrag[:-l], mfrag[-l:]
+                tmp_len = self.tls_session.rcs.mac_len
+                if tmp_len != 0:
+                    cfrag, mac = mfrag[:-tmp_len], mfrag[-tmp_len:]
                 else:
                     cfrag, mac = mfrag, b""
 
@@ -440,7 +445,7 @@ class TLS(_GenericTLSSessionInheritance):
                 is_mac_ok = self._tls_hmac_verify(chdr, cfrag, mac)
                 if not is_mac_ok:
                     pkt_info = self.firstlayer().summary()
-                    log_runtime.info("TLS: record integrity check failed [%s]", pkt_info)
+                    log_runtime.info("TLS: record integrity check failed [%s]", pkt_info)  # noqa: E501
 
         elif cipher_type == 'stream':
             # Decrypt
@@ -454,9 +459,9 @@ class TLS(_GenericTLSSessionInheritance):
                 mfrag = pfrag
 
                 # Extract MAC
-                l = self.tls_session.rcs.mac_len
-                if l != 0:
-                    cfrag, mac = mfrag[:-l], mfrag[-l:]
+                tmp_len = self.tls_session.rcs.mac_len
+                if tmp_len != 0:
+                    cfrag, mac = mfrag[:-tmp_len], mfrag[-tmp_len:]
                 else:
                     cfrag, mac = mfrag, b""
 
@@ -465,13 +470,13 @@ class TLS(_GenericTLSSessionInheritance):
                 is_mac_ok = self._tls_hmac_verify(chdr, cfrag, mac)
                 if not is_mac_ok:
                     pkt_info = self.firstlayer().summary()
-                    log_runtime.info("TLS: record integrity check failed [%s]", pkt_info)
+                    log_runtime.info("TLS: record integrity check failed [%s]", pkt_info)  # noqa: E501
 
         elif cipher_type == 'aead':
             # Authenticated encryption
             # crypto/cipher_aead.py prints a warning for integrity failure
             if (conf.crypto_valid_advanced and
-                isinstance(self.tls_session.rcs.cipher, Cipher_CHACHA20_POLY1305)):
+                    isinstance(self.tls_session.rcs.cipher, Cipher_CHACHA20_POLY1305)):  # noqa: E501
                 iv = b""
                 cfrag, mac = self._tls_auth_decrypt(hdr, efrag)
             else:
@@ -481,7 +486,7 @@ class TLS(_GenericTLSSessionInheritance):
         frag = self._tls_decompress(cfrag)
 
         if (decryption_success and
-            not isinstance(self.tls_session.rcs.cipher, Cipher_NULL)):
+                not isinstance(self.tls_session.rcs.cipher, Cipher_NULL)):
             self.deciphered_len = len(frag)
         else:
             self.deciphered_len = None
@@ -518,15 +523,14 @@ class TLS(_GenericTLSSessionInheritance):
         if s:
             try:
                 p = TLS(s, _internal=1, _underlayer=self,
-                        tls_session = self.tls_session)
+                        tls_session=self.tls_session)
             except KeyboardInterrupt:
                 raise
-            except:
+            except Exception:
                 p = conf.raw_layer(s, _internal=1, _underlayer=self)
             self.add_payload(p)
 
-
-    ### Building methods
+    # Building methods
 
     def _tls_compress(self, s):
         """
@@ -606,13 +610,13 @@ class TLS(_GenericTLSSessionInheritance):
         """
         # Compute the length of TLSPlaintext fragment
         hdr, frag = pkt[:5], pkt[5:]
-        l = len(frag)
-        hdr = hdr[:3] + struct.pack("!H", l)
+        tmp_len = len(frag)
+        hdr = hdr[:3] + struct.pack("!H", tmp_len)
 
         # Compression
         cfrag = self._tls_compress(frag)
-        l = len(cfrag)      # Update the length as a result of compression
-        hdr = hdr[:3] + struct.pack("!H", l)
+        tmp_len = len(cfrag)  # Update the length as a result of compression
+        hdr = hdr[:3] + struct.pack("!H", tmp_len)
 
         cipher_type = self.tls_session.wcs.cipher.type
 
@@ -622,7 +626,7 @@ class TLS(_GenericTLSSessionInheritance):
 
             # Excerpt below better corresponds to TLS 1.1 IV definition,
             # but the result is the same as with TLS 1.2 anyway.
-            #if self.version >= 0x0302:
+            # if self.version >= 0x0302:
             #    l = self.tls_session.wcs.cipher.block_size
             #    iv = randstring(l)
             #    mfrag = iv + mfrag
@@ -633,8 +637,8 @@ class TLS(_GenericTLSSessionInheritance):
             # Encryption
             if self.version >= 0x0302:
                 # Explicit IV for TLS 1.1 and 1.2
-                l = self.tls_session.wcs.cipher.block_size
-                iv = randstring(l)
+                tmp_len = self.tls_session.wcs.cipher.block_size
+                iv = randstring(tmp_len)
                 self.tls_session.wcs.cipher.iv = iv
                 efrag = self._tls_encrypt(pfrag)
                 efrag = iv + efrag
@@ -673,10 +677,11 @@ class TLS(_GenericTLSSessionInheritance):
 
 
 ###############################################################################
-### TLS ChangeCipherSpec                                                    ###
+#   TLS ChangeCipherSpec                                                      #
 ###############################################################################
 
-_tls_changecipherspec_type = { 1: "change_cipher_spec" }
+_tls_changecipherspec_type = {1: "change_cipher_spec"}
+
 
 class TLSChangeCipherSpec(_GenericTLSSessionInheritance):
     """
@@ -685,7 +690,7 @@ class TLSChangeCipherSpec(_GenericTLSSessionInheritance):
     Finished messages.
     """
     name = "TLS ChangeCipherSpec"
-    fields_desc = [ ByteEnumField("msgtype", 1, _tls_changecipherspec_type) ]
+    fields_desc = [ByteEnumField("msgtype", 1, _tls_changecipherspec_type)]
 
     def post_dissection_tls_session_update(self, msg_str):
         self.tls_session.triggered_prcs_commit = True
@@ -698,32 +703,33 @@ class TLSChangeCipherSpec(_GenericTLSSessionInheritance):
 
 
 ###############################################################################
-### TLS Alert                                                               ###
+#   TLS Alert                                                                 #
 ###############################################################################
 
-_tls_alert_level = { 1: "warning", 2: "fatal"}
+_tls_alert_level = {1: "warning", 2: "fatal"}
 
 _tls_alert_description = {
-    0: "close_notify",                 10: "unexpected_message",
-    20: "bad_record_mac",              21: "decryption_failed",
-    22: "record_overflow",             30: "decompression_failure",
-    40: "handshake_failure",           41: "no_certificate_RESERVED",
-    42: "bad_certificate",             43: "unsupported_certificate",
-    44: "certificate_revoked",         45: "certificate_expired",
-    46: "certificate_unknown",         47: "illegal_parameter",
-    48: "unknown_ca",                  49: "access_denied",
-    50: "decode_error",                51: "decrypt_error",
+    0: "close_notify", 10: "unexpected_message",
+    20: "bad_record_mac", 21: "decryption_failed",
+    22: "record_overflow", 30: "decompression_failure",
+    40: "handshake_failure", 41: "no_certificate_RESERVED",
+    42: "bad_certificate", 43: "unsupported_certificate",
+    44: "certificate_revoked", 45: "certificate_expired",
+    46: "certificate_unknown", 47: "illegal_parameter",
+    48: "unknown_ca", 49: "access_denied",
+    50: "decode_error", 51: "decrypt_error",
     60: "export_restriction_RESERVED", 70: "protocol_version",
-    71: "insufficient_security",       80: "internal_error",
-    90: "user_canceled",              100: "no_renegotiation",
-   110: "unsupported_extension",      111: "certificate_unobtainable",
-   112: "unrecognized_name",          113: "bad_certificate_status_response",
-   114: "bad_certificate_hash_value", 115: "unknown_psk_identity" }
+    71: "insufficient_security", 80: "internal_error",
+    90: "user_canceled", 100: "no_renegotiation",
+    110: "unsupported_extension", 111: "certificate_unobtainable",
+    112: "unrecognized_name", 113: "bad_certificate_status_response",
+    114: "bad_certificate_hash_value", 115: "unknown_psk_identity"}
+
 
 class TLSAlert(_GenericTLSSessionInheritance):
     name = "TLS Alert"
-    fields_desc = [ ByteEnumField("level", None, _tls_alert_level),
-                    ByteEnumField("descr", None, _tls_alert_description) ]
+    fields_desc = [ByteEnumField("level", None, _tls_alert_level),
+                   ByteEnumField("descr", None, _tls_alert_description)]
 
     def post_dissection_tls_session_update(self, msg_str):
         pass
@@ -733,12 +739,12 @@ class TLSAlert(_GenericTLSSessionInheritance):
 
 
 ###############################################################################
-### TLS Application Data                                                    ###
+#   TLS Application Data                                                      #
 ###############################################################################
 
 class TLSApplicationData(_GenericTLSSessionInheritance):
     name = "TLS Application Data"
-    fields_desc = [ StrField("data", "") ]
+    fields_desc = [StrField("data", "")]
 
     def post_dissection_tls_session_update(self, msg_str):
         pass
@@ -748,7 +754,7 @@ class TLSApplicationData(_GenericTLSSessionInheritance):
 
 
 ###############################################################################
-### Bindings                                                                ###
+#   Bindings                                                                  #
 ###############################################################################
 
 bind_layers(TCP, TLS, sport=443)
